==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescription } from "./TemplateSectionHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("TemplateSectionHeaderCellUpdatingEventArgs", function () { return new TemplateSectionHeaderCellUpdatingEventArgsDescription(); });
        a.z("TemplateSectionHeaderCellUpdatingEventArgs", TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateSectionHeaderCellUpdatingEventArgsDescription } from "./TemplateSectionHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("TemplateSectionHeaderCellUpdatingEventArgs", function () { return new TemplateSectionHeaderCellUpdatingEventArgsDescription(); });
        a.ab("TemplateSectionHeaderCellUpdatingEventArgs", TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderCellUpdatingEventArgsDescriptionMetadata };
